package com.ruoyi.jarvis.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.jarvis.mapper.PrdErrorTipMapper;
import com.ruoyi.jarvis.domain.PrdErrorTip;
import com.ruoyi.jarvis.service.IPrdErrorTipService;

/**
 * 商品错误提示Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-01-01
 */
@Service
public class PrdErrorTipServiceImpl implements IPrdErrorTipService 
{
    @Autowired
    private PrdErrorTipMapper prdErrorTipMapper;

    /**
     * 查询商品错误提示
     * 
     * @param id 商品错误提示主键
     * @return 商品错误提示
     */
    @Override
    public PrdErrorTip selectPrdErrorTipById(Long id)
    {
        return prdErrorTipMapper.selectPrdErrorTipById(id);
    }

    /**
     * 查询商品错误提示列表
     * 
     * @param prdErrorTip 商品错误提示
     * @return 商品错误提示
     */
    @Override
    public List<PrdErrorTip> selectPrdErrorTipList(PrdErrorTip prdErrorTip)
    {
        return prdErrorTipMapper.selectPrdErrorTipList(prdErrorTip);
    }

    /**
     * 新增商品错误提示
     * 
     * @param prdErrorTip 商品错误提示
     * @return 结果
     */
    @Override
    public int insertPrdErrorTip(PrdErrorTip prdErrorTip)
    {
        return prdErrorTipMapper.insertPrdErrorTip(prdErrorTip);
    }

    /**
     * 修改商品错误提示
     * 
     * @param prdErrorTip 商品错误提示
     * @return 结果
     */
    @Override
    public int updatePrdErrorTip(PrdErrorTip prdErrorTip)
    {
        return prdErrorTipMapper.updatePrdErrorTip(prdErrorTip);
    }

    /**
     * 批量删除商品错误提示
     * 
     * @param ids 需要删除的商品错误提示主键
     * @return 结果
     */
    @Override
    public int deletePrdErrorTipByIds(Long[] ids)
    {
        return prdErrorTipMapper.deletePrdErrorTipByIds(ids);
    }

    /**
     * 删除商品错误提示信息
     * 
     * @param id 商品错误提示主键
     * @return 结果
     */
    @Override
    public int deletePrdErrorTipById(Long id)
    {
        return prdErrorTipMapper.deletePrdErrorTipById(id);
    }

    /**
     * 根据错误代码和子代码查询错误提示
     * 
     * @param errCode 错误代码
     * @param errSubCode 错误子代码
     * @return 商品错误提示
     */
    @Override
    public PrdErrorTip selectPrdErrorTipByCode(String errCode, String errSubCode)
    {
        return prdErrorTipMapper.selectPrdErrorTipByCode(errCode, errSubCode);
    }
}
